# chatgpython

## Instalation

```commandline
pip install chatgpython
```

## Use

```python
from chatgptonic import ChatGPT

chat = ChatGPT("YOUR_API_KEY")

print(chat.send("Some answer"))  # Returns the API return
print(chat.just_chat("Some answer"))  # Returns just the ChatGPT response text
```


